Skip to contents

Meta data is some descriptions about the experiment, like the experiment type ("glycomics" or "glycoproteomics"), or the glycan type ("N", "O", "O-GalNAc", "O-Man", "O-Fuc", "O-GlcNAc", "O-Glc", "HMO", "GSL", "GAG", or "GPI").

[Deprecated]

This legacy API is retained temporarily for compatibility. Use GlycomicSE() or GlycoproteomicSE() as the default data container.

Usage

get_meta_data(exp, x = NULL)

get_exp_type(exp)

get_glycan_type(exp)

Arguments

exp

An experiment().

x

A string, the name of the meta data field. If NULL (default), a list of all meta data fields will be returned.

Value

The value of the meta data field. If the field does not exist, NULL will be returned.