Skip to contents

Set meta data values for the experiment, like the experiment type ("glycomics" or "glycoproteomics"), or the glycan type ("N", "O", "O-GalNAc", "O-Man", "O-Fuc", "O-GlcNAc", "O-Glc", "HMO", "GSL", "GAG", or "GPI").

[Deprecated]

This legacy API is retained temporarily for compatibility. Use GlycomicSE() or GlycoproteomicSE() as the default data container.

Usage

set_meta_data(exp, x, value)

set_exp_type(exp, value)

set_glycan_type(exp, value)

Arguments

exp

An experiment().

x

A string, the name of the meta data field.

value

The value to set for the meta data field.

Value

The modified experiment() object.