Skip to contents

Transforms a glycoproteomics-type experiment into a glycomics-type experiment by aggregating expression values by glycan structure (if available) or glycan composition.

This function implements the "pseudo-glycome" method described in doi:10.1038/s41467-026-68579-x , which aggregates glycoproteomic data by glycans to simulate glycome data when real glycome is unavailable.

Usage

as_pseudo_glycome(exp, aggr_method = c("sum", "mean", "median"))

Arguments

exp

A glycoproteomics experiment().

aggr_method

Aggregation method to use. One of "sum", "mean", or "median". Default is "sum". Note that glycopeptides can have different ionization efficiencies, so none of these methods are technically rigorous.

Value

A glycomics-type experiment() with aggregated expression values. The var_info will contain only glycan_composition and glycan_structure (if present in input) columns.

Details

Aggregation behavior:

  • If glycan_structure column exists in var_info, aggregation is done by glycan structure (more specific)

  • Otherwise, aggregation is done by glycan_composition

  • Expression values are aggregated within each glycan group using the specified aggr_method

Limitation: Glycopeptides can have different ionization efficiencies, so the aggregation operation is not technically rigorous regardless of the method used. Use results with caution.

Examples

library(glyrepr)
as_pseudo_glycome(real_experiment)
#> 
#> ── Glycomics Experiment ────────────────────────────────────────────────────────
#>  Expression matrix: 12 samples, 968 variables
#>  Sample information fields: group <fct>
#>  Variable information fields: glycan_structure <struct>, glycan_composition <comp>