Convert a SummarizedExperiment object to an experiment() object.
This function maps the SummarizedExperiment structure to experiment format:
The main assay becomes
expr_matcolDatabecomessample_inforowDatabecomesvar_infometadatabecomesmeta_data
This legacy API is retained temporarily for compatibility. Use
GlycomicSE() or GlycoproteomicSE() as the default data container.
Arguments
- se
A
SummarizedExperimentobject to convert.- assay_name
Character string specifying which assay to use. If NULL (default), uses the first assay.
- exp_type
Character string specifying experiment type. Must be either "glycomics", "glycoproteomics", "traitomics", "traitproteomics", or "others". If not supplied, will try to extract from metadata. If unavailable there, an error is issued.
- glycan_type
Character string specifying glycan type. Must be one of the valid
glycan_typevalues accepted byexperiment(). If not supplied, will try to extract from metadata. If unavailable there, an error is issued unlessexp_typeis "others", whereNULLis allowed.
Value
An experiment() object.